==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/modules/options/optw_ircoutput.h <==
#ifndef _OPTW_IRCOUTPUT_H_
#define _OPTW_IRCOUTPUT_H_

//
//   File : optw_ircoutput.h
//   Creation date : Wed Nov 15 2000 11:47:51 CEST by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2000 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_optionswidget.h"
#include <qlistview.h>

class QComboBox;

#define KVI_OPTIONS_WIDGET_ICON_KviIrcOutputOptionsWidget KVI_SMALLICON_RAW
#define KVI_OPTIONS_WIDGET_NAME_KviIrcOutputOptionsWidget __tr_no_lookup("Output")
#define KVI_OPTIONS_WIDGET_PARENT_KviIrcOutputOptionsWidget KviIrcOptionsWidget

class KviIrcOutputOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviIrcOutputOptionsWidget(QWidget * parent);
	~KviIrcOutputOptionsWidget();
protected:
	QComboBox * m_pVerbosityCombo;
protected:
	virtual void commit();
};

#endif //!_OPTW_IRCOUTPUT_H_

==> kvirc_3.2.4.orig.tar.gz: kvirc-3.2.4/src/modules/options/optw_ircoutput.h <==
#ifndef _OPTW_IRCOUTPUT_H_
#define _OPTW_IRCOUTPUT_H_

//
//   File : optw_ircoutput.h
//   Creation date : Wed Nov 15 2000 11:47:51 CEST by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 2000 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_optionswidget.h"
#include <qlistview.h>

class QComboBox;

#define KVI_OPTIONS_WIDGET_ICON_KviIrcOutputOptionsWidget KVI_SMALLICON_RAW
#define KVI_OPTIONS_WIDGET_NAME_KviIrcOutputOptionsWidget __tr2qs_no_lookup("Verbosity&Output")
#define KVI_OPTIONS_WIDGET_PARENT_KviIrcOutputOptionsWidget KviIrcOptionsWidget
#define KVI_OPTIONS_WIDGET_KEYWORDS_KviIrcOutputOptionsWidget __tr2qs_no_lookup("debug")
#define KVI_OPTIONS_WIDGET_PRIORITY_KviIrcOutputOptionsWidget 90000

class KviIrcOutputOptionsWidget : public KviOptionsWidget
{
	Q_OBJECT
public:
	KviIrcOutputOptionsWidget(QWidget * parent);
	~KviIrcOutputOptionsWidget();
protected:
	QComboBox * m_pVerbosityCombo;
protected:
	virtual void commit();
};

#endif //!_OPTW_IRCOUTPUT_H_
